/**
 * Copyright 2009 Ashley Williams
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you
 * may not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package acme;

import java.io.File;
import java.io.IOException;

import org.apache.commons.io.FileUtils;

import protoj.lang.PublishFeature;

/**
 * See the individual pieces of advice.
 * 
 * @author Ashley Williams
 *
 */
public final aspect FakeSignature {
	/**
	 * Replaces the createSig method with an implementation that just
	 * creates the sig file. This is because setting up gpg keys on each test machine
	 * is too complex. The parameters are made available for testing.
	 * This advice only gets applied when the createSig method executes in the
	 * AcmeProject.main callstack.
	 * 
	 * 
	 * @param options
	 * @param artifact
	 * @param artifactSig
	 * @return
	 */
	File around(String options, File artifact, File artifactSig) :
		execution(File PublishFeature.executeGpgCommand(String, File, File))
		&& args(options, artifact, artifactSig)
		&& cflow(execution(* AcmeProject.main(..)))
	{
		try {
			artifactSig.createNewFile();
			FileUtils.writeStringToFile(artifactSig, "-----FAKE PGP SIGNATURE-----");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		
		return artifactSig;
	}
}
