/**
 * Copyright 2009 Ashley Williams
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you
 * may not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package acme.core;

import protoj.lang.CompileFeature;
import protoj.lang.StandardProject;
import protoj.util.ArgRunnable;

/**
 * Contains just the use-cases to compile and delegate to the AcmeProject class.
 * 
 * 
 * @author Ashley Williams
 * 
 */
public final class AcmeCore {
	public static void main(String[] args) {
		new AcmeCore(args).dispatchCommands();
	}

	private StandardProject project;

	/**
	 * 
	 * @param args
	 */
	public AcmeCore(String[] args) {
		project = new StandardProject(args, getAcmeVersion());
		project.getDispatchFeature().initLoadTimeWeaving(null);
		project.getDispatchFeature().initBootstrap("acme.AcmeProject", "16m");
		project.initDirConfig();

		project.getResourceFeature().getContext().put("acme", this);
		project.getRetrieveFeature().initIvy("/acme/ivy.xml");
		project.getCompileFeature().initConfig(true,
				new ArgRunnable<CompileFeature>() {
					public void run(CompileFeature feature) {
						feature.initAjcMemory("16m");
						feature.initAjcSource("1.5");
					}
				});
	}

	public void dispatchCommands() {
		project.getDispatchFeature().dispatchCommands();
	}

	public StandardProject getProject() {
		return project;
	}

	public String getJunitVersion() {
		return "4.4";
	}

	public String getAcmeVersion() {
		return "1.0";
	}

}
