package org.basic.core;

import protoj.lang.CompileFeature;
import protoj.lang.StandardProject;
import protoj.util.ArgRunnable;

/**
 * A very basic but valid project.
 * 
 * @author Ashley Williams
 * 
 */
public final class BasicCore {
	public static void main(String[] args) {
		BasicCore core = new BasicCore(args);

		// process the commands captured from the command line
		core.dispatchCommands();
	}

	/**
	 * The main ProtoJ pojo.
	 */
	private StandardProject project;

	public BasicCore(String[] args) {
		project = new StandardProject(args, "basic Version 1.0");

		// enables configuration support with no resolving of ${x} placeholders
		// so that files from conf/profile get merged to the project root tree
		project.initDirConfig();

		// project resources can access the project code with velocity markup -
		// eg the maven and ivy files don't have to use hard-coded values
		project.getResourceFeature().getContext().put("basic", this);

		// the specified ivy.xml file will be use for downloading dependencies
		project.getRetrieveFeature().initIvy("/basic/ivy.xml");

		// the ajc compiler is used to compile the entire project
		project.getCompileFeature().initConfig(false,
				new ArgRunnable<CompileFeature>() {
					public void run(CompileFeature feature) {
						feature.getJavacCompileTask().getCompileTask()
								.setMemoryMaximumSize("16m");
						feature.getJavacCompileTask().getCompileTask()
								.setSource("1.5");
					}
				});

		// a new vm is used to run all commands with the specified main class
		project.getDispatchFeature().initBootstrap(
				"org.basic.system.BasicProject", "16m");
	}

	/**
	 * This method is accessed from inside the ivy.xml resource, using velocity
	 * markup, instead of hard-coding the value.
	 * 
	 * @return
	 */
	public String getJunitVersion() {
		return "4.4";
	}

	/**
	 * This method is accessed from inside the ivy.xml resource, using velocity
	 * markup, instead of hard-coding the value.
	 * 
	 * @return
	 */
	public String getBasicVersion() {
		return "1.0";
	}

	/**
	 * Returns a reference to the main project pojo.
	 * 
	 * @return
	 */
	public StandardProject getProject() {
		return project;
	}

	/**
	 * Begins dispatching commands specified at the command line
	 */
	public void dispatchCommands() {
		getProject().getDispatchFeature().dispatchCommands();
	}

}
