package helloworld;

import protoj.lang.StandardProject;

/**
 * An extremely simple class that demonstrates some of the features available
 * from the ProtoJ library. Without much effort the HelloWorld project acquires
 * use-cases for junit testing, assembly and tar creation and more.
 * <p>
 * To set up simply take a copy of all the jars from the ProtoJ lib directory
 * and place them in the lib directory for this HelloWorld project. Then you can
 * go ahead and try executing a selection of the following commands from the
 * HelloWorld project bin directory:
 * 
 * <pre>
 * bin$ ./helloworld.sh help
 * bin$ ./helloworld.sh archive
 * bin$ ./helloworld.sh hello-world
 * bin$ ./helloworld.sh clean
 * </pre>
 * 
 * @author Ashley Williams
 */
public final class HelloWorld {
	/**
	 * The helloworld.sh bash shell script enters here.
	 * 
	 * @param args
	 */
	public static void main(String[] args) {
		// the central domain object is created with the command line
		// arguments and some additional version information
		StandardProject project = new StandardProject(args, "9.9");

		// enables configuration support with no resolving of ${x} placeholders
		// so that files from conf/profile get merged to the project root tree
		project.initDirConfig();

		// enables junit testing with the specified amount of memory
		project.initJunit("16m");

		// enables classes jar file creation with the specified jar name
		project.getArchiveFeature().addClasses("hello-world-9.9");

		// enables source file archive creation with the specified jar name
		project.getArchiveFeature().addSources("hello-world-9.9");

		// enables javadoc archive creation with the specified jar name
		// and maximum memory that the javadoc tool should allocate
		project.getArchiveFeature().addJavadoc("hello-world-9.9", "16m");

		// enables project tar creation with the specified file name
		// and root directory prefix inside the tar
		project.getArchiveFeature().initProjectArchive("hello-world",
				"hello-world-9.9");
		project.getCommandStore().addCommand("hello-world", "16m",
				new Runnable() {
					public void run() {
						System.out.println("Hello World!");
					}
				}).initHelpString("writes to the console");

		// adds a command for a new project use-case including the maximum
		// amount of memory required in the new vm that will be started for it
		project.getDispatchFeature().dispatchCommands();
	}
}
