package org.serverdemo.system;

import java.io.File;

import org.apache.log4j.Appender;
import org.apache.log4j.Logger;
import org.apache.log4j.PatternLayout;
import org.apache.log4j.RollingFileAppender;

/**
 * Simple demonstration aspect that merely logs calls
 * to methods on some jboss instance.
 * 
 * @author Ashley Williams
 *
 */
public final aspect JbossWatcher {
	private Logger logger;
	
	/**
	 * Adds a log call before the execution of Ejb3Deployer methods.
	 */
	before() : execution(* org.jboss.ejb3.deployers.Ejb3Deployer.*(..)) {
		String signature = thisJoinPoint.getSignature().toShortString();
		logger.info("serverdemo has detected a call to " + signature);
	}
	
	/**
	 * The logger is created with a single file appender that is configured
	 * to write output to the jboss bin directory.
	 */
	public JbossWatcher() {
		// we are running from the jboss bin directory so will have to
		// navigate to project log directory
		File logFile = new File(".", "serverdemo.log");
		String path = logFile.getAbsolutePath();
		logger = Logger.getLogger("serverdemo");
		String name = "serverdemo.fileAppender";

		String pattern = "%d{HH:mm:ss,SSS} [%t] %m%n";
		PatternLayout layout = new PatternLayout(pattern);
		Appender appender = new RollingFileAppender(layout, path);
		appender.setName(name);
		logger.addAppender(appender);
	}
}
